==> openshift-model-config-6.3.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OAuthListFluent<A extends OAuthListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,OAuth item);
  public A setToItems(Integer index,OAuth item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.OAuth... items);
  public A addAllToItems(Collection<OAuth> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.OAuth... items);
  public A removeAllFromItems(Collection<OAuth> items);
  public A removeMatchingFromItems(Predicate<OAuthBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<OAuth> getItems();
  public List<OAuth> buildItems();
  public OAuth buildItem(Integer index);
  public OAuth buildFirstItem();
  public OAuth buildLastItem();
  public OAuth buildMatchingItem(Predicate<OAuthBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<OAuthBuilder> predicate);
  public A withItems(List<OAuth> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.OAuth... items);
  public Boolean hasItems();
  public OAuthListFluent.ItemsNested<A> addNewItem();
  public OAuthListFluent.ItemsNested<A> addNewItemLike(OAuth item);
  public OAuthListFluent.ItemsNested<A> setNewItemLike(Integer index,OAuth item);
  public OAuthListFluent.ItemsNested<A> editItem(Integer index);
  public OAuthListFluent.ItemsNested<A> editFirstItem();
  public OAuthListFluent.ItemsNested<A> editLastItem();
  public OAuthListFluent.ItemsNested<A> editMatchingItem(Predicate<OAuthBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,OAuthFluent<OAuthListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthListFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OAuthListFluent<A extends OAuthListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,OAuth item);
  public A setToItems(int index,OAuth item);
  public A addToItems(io.fabric8.openshift.api.model.config.v1.OAuth... items);
  public A addAllToItems(Collection<OAuth> items);
  public A removeFromItems(io.fabric8.openshift.api.model.config.v1.OAuth... items);
  public A removeAllFromItems(Collection<OAuth> items);
  public A removeMatchingFromItems(Predicate<OAuthBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<OAuth> getItems();
  public List<OAuth> buildItems();
  public OAuth buildItem(int index);
  public OAuth buildFirstItem();
  public OAuth buildLastItem();
  public OAuth buildMatchingItem(Predicate<OAuthBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<OAuthBuilder> predicate);
  public A withItems(List<OAuth> items);
  public A withItems(io.fabric8.openshift.api.model.config.v1.OAuth... items);
  public Boolean hasItems();
  public OAuthListFluent.ItemsNested<A> addNewItem();
  public OAuthListFluent.ItemsNested<A> addNewItemLike(OAuth item);
  public OAuthListFluent.ItemsNested<A> setNewItemLike(int index,OAuth item);
  public OAuthListFluent.ItemsNested<A> editItem(int index);
  public OAuthListFluent.ItemsNested<A> editFirstItem();
  public OAuthListFluent.ItemsNested<A> editLastItem();
  public OAuthListFluent.ItemsNested<A> editMatchingItem(Predicate<OAuthBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,OAuthFluent<OAuthListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
